@@ -4,7 +4,7 @@ from .thermocline_array import ThermoclineArrayOMPAProblem
 from .endmemberpenaltyfunc import EndMemExpPenaltyFunc
 from .plotting import (plot_ompasoln_endmember_fractions,
                        plot_ompasoln_residuals,
-                       plot_ompaproblem_endmember_usagepenalties,
+                       plot_ompasoln_endmember_usagepenalties,
                        plot_thermocline_endmember_fractions,
                        plot_thermocline_residuals,
                        build_altair_viz, build_thermocline_altair_viz)
